@@ -1,14 +1,6 @@
-use crate::{AtRule, Block, CustomIdent, Ident, Percent, Str};
+use crate::{Block, CustomIdent, Ident, Percent, Str};
 use swc_common::{ast_node, Span};
 
-#[ast_node]
-pub enum KeyframesName {
-    #[tag("CustomIdent")]
-    CustomIdent(CustomIdent),
-    #[tag("Str")]
-    Str(Str),
-}
-
 #[ast_node("KeyframesRule")]
 pub struct KeyframesRule {
     pub span: Span,
@@ -16,11 +8,19 @@ pub struct KeyframesRule {
     pub blocks: Vec<KeyframeBlock>,
 }
 
+#[ast_node]
+pub enum KeyframesName {
+    #[tag("CustomIdent")]
+    CustomIdent(CustomIdent),
+    #[tag("Str")]
+    Str(Str),
+}
+
 #[ast_node]
 pub struct KeyframeBlock {
     pub span: Span,
-    pub selector: Vec<KeyframeSelector>,
-    pub rule: KeyframeBlockRule,
+    pub prelude: Vec<KeyframeSelector>,
+    pub block: Block,
 }
 
 #[ast_node]
@@ -30,12 +30,3 @@ pub enum KeyframeSelector {
     #[tag("Percent")]
     Percent(Percent),
 }
-
-#[ast_node]
-pub enum KeyframeBlockRule {
-    #[tag("Block")]
-    Block(Box<Block>),
-
-    #[tag("*")]
-    AtRule(Box<AtRule>),
-}
