@@ -1,11 +1,11 @@
-use crate::{Ident, Number, Ratio, Rule, UnitValue};
+use crate::{Dimension, Ident, Number, Ratio, Rule};
 use string_enum::StringEnum;
 use swc_common::{ast_node, EqIgnoreSpan, Span};
 
 #[ast_node("MediaRule")]
 pub struct MediaRule {
     pub span: Span,
-    pub media: MediaQueryList,
+    pub media: Option<MediaQueryList>,
     pub rules: Vec<Rule>,
 }
 
@@ -125,8 +125,8 @@ pub enum MediaFeatureValue {
     #[tag("Number")]
     Number(Number),
 
-    #[tag("UnitValue")]
-    Dimension(UnitValue),
+    #[tag("Dimension")]
+    Dimension(Dimension),
 
     #[tag("Ident")]
     Ident(Ident),
